.sidebar-toolbar {
	border: 0;
	border-radius: 0;
}

.primary-toolbar {
	border-bottom: solid 1px @borders;
}

.floating-bar {
	padding: 1px;
	background-color: @theme_base_color;
	border-width: 1px;
	border-style: solid solid none;
	border-color: @borders;
	border-radius: 3px 0 0 0;
	border-right-style: none;
}

.floating-bar:backdrop {
	background-color: @theme_unfocused_base_color;
	border-color: @unfocused_borders;
}
